@@ -5,6 +5,7 @@
 
 
 import pyscal.traj_process as ptp
+from pyscal.formats.ase import convert_snap
 import pyscal.routines as routines
 import os
 import numpy as np
@@ -85,6 +86,15 @@ class System(pc.System):
         self.actual_box = None
         pc.System.__init__(self)
 
+    #iterator for atoms
+    def iter_atoms(self):
+        """
+        Iter over atoms
+        """
+        for i in range(self.natoms):
+            yield self.cget_atom(i)
+
+
     @property
     def box(self):
         """
@@ -1677,6 +1687,20 @@ class System(pc.System):
             timestep = timestep, species = species)
 
 
+    def to_ase(self, species):
+        """
+        Convert system to an ASE Atoms object
+
+        Parameters
+        ----------
+        species : list of string
+            The chemical species
+
+        Returns
+        -------
+        None
+        """
+        return convert_snap(self, species=species)
 
     def calculate_energy(self, species='Au', pair_style=None, 
                                         pair_coeff=None, mass=1.0,
